@@ -4,10 +4,13 @@ from django.contrib.contenttypes.models import ContentType
 from django.core.cache import cache
 from django.db import models
 from django.db.models.fields import GenericIPAddressField as IPAddressField
-from django.db.models.signals import post_save, pre_delete, pre_save
+from django.db.models.signals import post_save
+from django.db.models.signals import pre_delete
+from django.db.models.signals import pre_save
 from django.urls import reverse
 from django.utils import translation
 from django.utils.safestring import mark_safe
+from django.utils.text import slugify
 from django.utils.translation import gettext_lazy as _
 from mptt.models import MPTTModel
 from wiki import managers
@@ -40,7 +43,10 @@ class Article(models.Model):
         ),
     )
 
-    created = models.DateTimeField(auto_now_add=True, verbose_name=_("created"),)
+    created = models.DateTimeField(
+        auto_now_add=True,
+        verbose_name=_("created"),
+    )
     modified = models.DateTimeField(
         auto_now=True,
         verbose_name=_("modified"),
@@ -184,7 +190,8 @@ class Article(models.Model):
     @classmethod
     def get_for_object(cls, obj):
         return ArticleForObject.objects.get(
-            object_id=obj.id, content_type=ContentType.objects.get_for_model(obj),
+            object_id=obj.id,
+            content_type=ContentType.objects.get_for_model(obj),
         ).article
 
     def __str__(self):
@@ -217,15 +224,19 @@ class Article(models.Model):
         """Returns per-article cache key."""
         lang = translation.get_language()
 
-        return "wiki:article:{id}:{lang}".format(
+        key_raw = "wiki:article:{id}:{lang}".format(
             id=self.current_revision.id if self.current_revision else self.id, lang=lang
         )
+        # https://github.com/django-wiki/django-wiki/issues/1065
+        return slugify(key_raw, allow_unicode=True)
 
     def get_cache_content_key(self, user=None):
         """Returns per-article-user cache key."""
-        return "{key}:{user}".format(
+        key_raw = "{key}:{user}".format(
             key=self.get_cache_key(), user=user.get_username() if user else ""
         )
+        # https://github.com/django-wiki/django-wiki/issues/1065
+        return slugify(key_raw, allow_unicode=True)
 
     def get_cached_content(self, user=None):
         """Returns cached version of rendered article.
@@ -303,8 +314,13 @@ class BaseRevisionMixin(models.Model):
         editable=False, verbose_name=_("revision number")
     )
 
-    user_message = models.TextField(blank=True,)
-    automatic_log = models.TextField(blank=True, editable=False,)
+    user_message = models.TextField(
+        blank=True,
+    )
+    automatic_log = models.TextField(
+        blank=True,
+        editable=False,
+    )
 
     ip_address = IPAddressField(_("IP address"), blank=True, null=True, editable=False)
     user = models.ForeignKey(
@@ -325,8 +341,14 @@ class BaseRevisionMixin(models.Model):
     # NOTE! The semantics of these fields are not related to the revision itself
     # but the actual related object. If the latest revision says "deleted=True" then
     # the related object should be regarded as deleted.
-    deleted = models.BooleanField(verbose_name=_("deleted"), default=False,)
-    locked = models.BooleanField(verbose_name=_("locked"), default=False,)
+    deleted = models.BooleanField(
+        verbose_name=_("deleted"),
+        default=False,
+    )
+    locked = models.BooleanField(
+        verbose_name=_("locked"),
+        default=False,
+    )
 
     def set_from_request(self, request):
         if request.user.is_authenticated:
